@@ -484,6 +484,24 @@ class DuckDB(Dialect):
             TokenType.SHOW: lambda self: self._parse_show(),
         }
 
+        SET_PARSERS = {
+            **parser.Parser.SET_PARSERS,
+            "VARIABLE": lambda self: self._parse_set_item_assignment("VARIABLE"),
+        }
+
+        def _parse_lambda(self, alias: bool = False) -> t.Optional[exp.Expression]:
+            index = self._index
+            if not self._match_text_seq("LAMBDA"):
+                return super()._parse_lambda(alias=alias)
+
+            expressions = self._parse_csv(self._parse_lambda_arg)
+            if not self._match(TokenType.COLON):
+                self._retreat(index)
+                return None
+
+            this = self._replace_lambda(self._parse_assignment(), expressions)
+            return self.expression(exp.Lambda, this=this, expressions=expressions, colon=True)
+
         def _parse_expression(self) -> t.Optional[exp.Expression]:
             # DuckDB supports prefix aliases, e.g. foo: 1
             if self._next and self._next.token_type == TokenType.COLON:
@@ -891,6 +909,19 @@ class DuckDB(Dialect):
             exp.NthValue,
         )
 
+        def lambda_sql(
+            self, expression: exp.Lambda, arrow_sep: str = "->", wrap: bool = True
+        ) -> str:
+            if expression.args.get("colon"):
+                prefix = "LAMBDA "
+                arrow_sep = ":"
+                wrap = False
+            else:
+                prefix = ""
+
+            lambda_sql = super().lambda_sql(expression, arrow_sep=arrow_sep, wrap=wrap)
+            return f"{prefix}{lambda_sql}"
+
         def show_sql(self, expression: exp.Show) -> str:
             return f"SHOW {expression.name}"
 
