@@ -271,6 +271,17 @@ class TestDuckDB(Validator):
             parse_one("a // b", read="duckdb").assert_is(exp.IntDiv).sql(dialect="duckdb"), "a // b"
         )
 
+        self.validate_identity(
+            "SELECT LIST_TRANSFORM([5, NULL, 6], (x, y) -> COALESCE(x, y, 0) + 1)"
+        )
+        self.validate_identity(
+            "SELECT LIST_TRANSFORM([5, NULL, 6], LAMBDA x, y : COALESCE(x, y, 0) + 1)"
+        )
+        self.validate_identity(
+            "SELECT LIST_TRANSFORM(LIST_FILTER([0, 1, 2, 3, 4, 5], LAMBDA x : x % 2 = 0), LAMBDA y : y * y)"
+        )
+        self.validate_identity("SELECT LIST_TRANSFORM([5, NULL, 6], LAMBDA x : COALESCE(x, 0) + 1)")
+        self.validate_identity("SELECT LIST_TRANSFORM(nbr, LAMBDA x : x + 1) FROM article AS a")
         self.validate_identity("SELECT * FROM my_ducklake.demo AT (VERSION => 2)")
         self.validate_identity("SELECT UUIDV7()")
         self.validate_identity("SELECT TRY(LOG(0))")
@@ -1675,3 +1686,12 @@ class TestDuckDB(Validator):
             with self.subTest(f"Testing DuckDB EXTRACT({part} FROM foo)"):
                 # All of these should remain as is, they don't have synonyms
                 self.validate_identity(f"EXTRACT({part} FROM foo)")
+
+    def test_set_item(self):
+        self.validate_identity("SET memory_limit = '10GB'")
+        self.validate_identity("SET SESSION default_collation = 'nocase'")
+        self.validate_identity("SET GLOBAL sort_order = 'desc'")
+        self.validate_identity("SET VARIABLE my_var = 30")
+        self.validate_identity("SET VARIABLE location_map = (SELECT foo FROM bar)")
+
+        self.validate_identity("SET VARIABLE my_var TO 30", "SET VARIABLE my_var = 30")
