@@ -52,6 +52,39 @@ ARRAY<DOUBLE>;
 ARRAY_SLICE([1, 1.5], 1, 2);
 ARRAY<DOUBLE>;
 
+FROM_BASE64(tbl.str_col);
+BINARY;
+
+ANY_VALUE(tbl.str_col);
+STRING;
+
+ANY_VALUE(tbl.array_col);
+ARRAY<STRING>;
+
+CHR(65);
+VARCHAR;
+
+COUNTIF(tbl.bigint_col > 1);
+BIGINT;
+
+LAST_VALUE(tbl.bigint_col) OVER (ORDER BY tbl.bigint_col);
+BIGINT;
+
+TO_BASE64(tbl.bytes_col);
+VARCHAR;
+
+UNIX_DATE(tbl.date_col);
+BIGINT;
+
+UNIX_SECONDS(tbl.timestamp_col);
+BIGINT;
+
+STARTS_WITH(tbl.str_col, prefix);
+BOOLEAN;
+
+ENDS_WITH(tbl.str_col, suffix);
+BOOLEAN;
+
 --------------------------------------
 -- Spark2 / Spark3 / Databricks
 --------------------------------------
@@ -496,6 +529,70 @@ DOUBLE;
 ARRAY_LAST([1, 1.5]);
 DOUBLE;
 
+# dialect: bigquery
+GENERATE_ARRAY(1, 5, 0.3);
+ARRAY<DOUBLE>;
+
+# dialect: bigquery
+GENERATE_ARRAY(1, 5);
+ARRAY<BIGINT>;
+
+# dialect: bigquery
+GENERATE_ARRAY(1, 2.5);
+ARRAY<DOUBLE>;
+
+# dialect: bigquery
+INT64(JSON '999');
+BIGINT;
+
+# dialect: bigquery
+LOGICAL_AND(tbl.bool_col);
+BOOLEAN;
+
+# dialect: bigquery
+LOGICAL_OR(tbl.bool_col);
+BOOLEAN;
+
+# dialect: bigquery
+MAKE_INTERVAL(1, 6, 15);
+INTERVAL;
+
+# dialect: bigquery
+SHA1(tbl.str_col);
+BINARY;
+
+# dialect: bigquery
+SHA256(tbl.str_col);
+BINARY;
+
+# dialect: bigquery
+SHA512(tbl.str_col);
+BINARY;
+
+# dialect: bigquery
+CORR(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: bigquery
+COVAR_POP(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: bigquery
+COVAR_SAMP(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: bigquery
+DATETIME(2025, 1, 1, 12, 0, 0);
+DATETIME;
+
+# dialect: bigquery
+LAG(tbl.bigint_col, 1 , 2.5) OVER (ORDER BY tbl.bigint_col);
+DOUBLE;
+
+# dialect: bigquery
+LAG(tbl.bigint_col, 1 , 2) OVER (ORDER BY tbl.bigint_col);
+BIGINT;
+
 --------------------------------------
 -- Snowflake
 --------------------------------------
